<?php
/**
 * Plugin Name: Reoon Email Verifier for Fluent Forms
 * Description: A plugin to validate email fields in Fluent Forms using the Reoon Email Verifier API.
 * Version: 1.1
 * Author: WpScriptly
 */

// Hook to register admin menu
add_action('admin_menu', 'reoon_email_verifier_add_admin_menu');

// Hook to register plugin settings
add_action('admin_init', 'reoon_email_verifier_register_settings');

function reoon_email_verifier_add_admin_menu() {
    add_options_page(
        'Reoon Email Verifier Settings',
        'Reoon Email Verifier',
        'manage_options',
        'reoon-email-verifier',
        'reoon_email_verifier_settings_page'
    );
}

function reoon_email_verifier_register_settings() {
    register_setting('reoon_email_verifier_settings', 'reoon_target_form_ids');
    register_setting('reoon_email_verifier_settings', 'reoon_api_key');
}

function reoon_email_verifier_settings_page() {
    ?>
    <div class="wrap">
        <h1>Reoon Email Verifier Settings</h1>
        <form method="post" action="options.php">
            <?php settings_fields('reoon_email_verifier_settings'); ?>
            <?php do_settings_sections('reoon_email_verifier_settings'); ?>

            <table class="form-table">
                <tr valign="top">
                    <th scope="row">Target Form IDs</th>
                    <td>
                        <input type="text" name="reoon_target_form_ids" value="<?php echo esc_attr(get_option('reoon_target_form_ids', '')); ?>" />
                        <p class="description">Enter the Fluent Form IDs you want to validate, separated by commas (e.g., 1,2,3).</p>
                    </td>
                </tr>

                <tr valign="top">
                    <th scope="row">Reoon API Key</th>
                    <td>
                        <input type="text" name="reoon_api_key" value="<?php echo esc_attr(get_option('reoon_api_key', '')); ?>" />
                        <p class="description">Enter your Reoon API key here. Don't have an API key? <a href="https://emailverifier.reoon.com/register/?inv=f2fz0to4" target="_blank">Register for a Reoon API key</a>.</p>
                    </td>
                </tr>
            </table>

            <?php submit_button(); ?>
        </form>

        <h2>How to Use:</h2>
        <p>This plugin validates the email fields of Fluent Forms using the Reoon Email Verifier API.</p>
        <p>It checks the emails against the form IDs you specify and uses your API key to verify the validity of the email.</p>
        <p>You can customize the settings on this page by entering the form IDs you wish to validate and your Reoon API key.</p>
        <p>You can add more than 1 form to the form ID (1,2,3,4) Use coma's to seperate them.</p>
    </div>
    <?php
}

// Email validation filter using the Reoon API
add_filter('fluentform/validate_input_item_input_email', function ($default, $field, $formData, $fields, $form) {

    // Get settings from the admin panel
    $targetFormIds = array_map('trim', explode(',', get_option('reoon_target_form_ids', '')));
    $reoonApiKey = get_option('reoon_api_key', '');
    
    $errorMessage = 'This email address is invalid or has been reported as spam before!'; // Custom error message
    
    // Check if the current form's ID matches one of the target form IDs
    if (!in_array($form->id, $targetFormIds) || empty($reoonApiKey)) {
        return $default;
    }

    $fieldName = 'email'; // Update this to match the name of the email field in your form
    
    // Check if the email field is empty
    if (empty($formData[$fieldName])) {
        return $default;
    }
    
    $email = $formData[$fieldName];

    // Send a request to the Reoon API to verify the email
    $request = wp_remote_get('https://emailverifier.reoon.com/api/verify?email='.urlencode($email).'&key='.urlencode($reoonApiKey).'&mode=power');

    // Check if the request resulted in an error
    if (is_wp_error($request)) {
        return $default; // Request failed, so skip validation
    }

    // Retrieve the response from the Reoon API and decode it as JSON
    $response = wp_remote_retrieve_body($request);
    $response = json_decode($response, true);

    // If the email is valid, return the default result
    if (isset($response['status']) && $response['status'] === 'valid') {
        return $default;
    }

    // If the email is not valid, return the custom error message
    return $errorMessage;

}, 10, 5);
